@@ -1,12 +1,6 @@
-# -*- coding: utf-8 -*-
-#
 # Copyright 2019 SoloKeys Developers
-# Copyright 2022 Nitrokey Developers
-#
-# Licensed under the Apache License, Version 2.0, <LICENSE-APACHE or
-# http://apache.org/licenses/LICENSE-2.0> or the MIT license <LICENSE-MIT or
-# http://opensource.org/licenses/MIT>, at your option. This file may not be
-# copied, modified, or distributed except according to those terms.
+# Copyright Nitrokey GmbH
+# SPDX-License-Identifier: Apache-2.0 OR MIT
 
 import logging
 import os
@@ -31,8 +25,6 @@ from pynitrokey.cli.storage import storage
 from pynitrokey.confconsts import LOG_FN, LOG_FORMAT
 from pynitrokey.helpers import filter_sensitive_parameters, local_critical
 
-# from . import _patches  # noqa  (since otherwise "unused")
-
 logger = logging.getLogger(__name__)
 
 
@@ -84,6 +76,10 @@ def nitropy():
     check_root()
 
 
+from . import nkfido2
+
+nkfido2.add_commands(fido2)
+
 nitropy.add_command(fido2)
 nitropy.add_command(nethsm)
 nitropy.add_command(nk3)
